@@ -10,7 +10,6 @@
 
 #include "EditVBoxLayout.h"
 #include "AbcApplication.h"
-#include "PreferencesMenu.h"
 #include "settings.h"
 #include <QFileInfo>
 #include <QDebug>
@@ -43,6 +42,7 @@ EditVBoxLayout::EditVBoxLayout(const QString& fileName, QWidget* parent)
 
     connect(&xspinbox, SIGNAL(valueChanged(int)), this, SLOT(onXChanged(int)));
     connect(&abcplaintextedit, &QPlainTextEdit::selectionChanged, this, &EditVBoxLayout::onSelectionChanged);
+    connect(&abcplaintextedit, &QPlainTextEdit::cursorPositionChanged, this, &EditVBoxLayout::onCursorPositionChanged);
     connect(&playpushbutton, SIGNAL(clicked()), this, SLOT(onPlayClicked()));
     connect(&runpushbutton, &QPushButton::clicked, this, &EditVBoxLayout::onRunClicked);
 
@@ -77,17 +77,51 @@ int EditVBoxLayout::xOfCursor(const QTextCursor& c) {
     int i = 0;
     QStringList lines = all.split('\n');
 
+    /* look if line under cursor is an X: */
+    QTextCursor tc(c);
+    tc.select(QTextCursor::LineUnderCursor);
+    if (tc.selectedText().startsWith("X:")) {
+        bool ok = false;
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+        x = tc.selectedText().midRef(2).toInt(&ok);
+#else
+        x = tc.selectedText().mid(2).toInt(&ok);
+#endif
+        if (ok) {
+            return x;
+        } else {
+            x = 1;
+        }
+    }
+
     /* find last X: before selectionIndex */
     for (int l = 0; l < lines.count() && i < index; l++) {
-        i += lines.at(l).count() +1; /* count \n */
+        i += lines.at(l).size() +1; /* count \n */
         if (lines.at(l).startsWith("X:")) {
-            x = lines.at(l).right(1).toInt();
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+            x = lines.at(l).midRef(2).toInt();
+#else
+            x = lines.at(l).mid(2).toInt();
+#endif
         }
     }
 
     return x;
 }
 
+void EditVBoxLayout::onCursorPositionChanged()
+{
+    in_cursor_position_changed = true;
+    AbcPlainTextEdit* te = qobject_cast<AbcPlainTextEdit*>(sender());
+    QTextCursor tc = te->textCursor();
+    int x = xOfCursor(tc);
+
+    if (xspinbox.value() == x)
+        in_cursor_position_changed = false;
+    else
+        xspinbox.setValue(x);
+}
+
 void EditVBoxLayout::onSelectionChanged()
 {
     QTextCursor c = abcPlainTextEdit()->textCursor();
@@ -97,9 +131,6 @@ void EditVBoxLayout::onSelectionChanged()
     } else {
         selection.clear();
         selectionIndex = c.selectionStart();
-        /* set X spinbox */
-        int x = xOfCursor(c);
-        xspinbox.setValue(x);
     }
 }
 
@@ -115,9 +146,13 @@ void EditVBoxLayout::exportMIDI() {
 
         /* find last X: before selectionIndex */
         for (int l = 0; l < lines.count() && i < selectionIndex; l++) {
-            i += lines.at(l).count() +1; /* count \n */
+            i += lines.at(l).size() +1; /* count \n */
             if (lines.at(l).startsWith("X:")) {
-                xspinbox.setValue(lines.at(l).right(1).toInt());
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+                xspinbox.setValue(lines.at(l).midRef(2).toInt());
+#else
+                xspinbox.setValue(lines.at(l).mid(2).toInt());
+#endif
                 xl = l;
                 /* don't break on first X: continue until selectionIndex */
             }
@@ -230,7 +265,11 @@ void EditVBoxLayout::cleanup()
 
 void EditVBoxLayout::onXChanged(int value)
 {
-    qDebug() << value;
+    if (!in_cursor_position_changed) {
+        abcPlainTextEdit()->findX(value);
+    }
+
+    in_cursor_position_changed = false;
 }
 
 void EditVBoxLayout::spawnCompiler(const QString &prog, const QStringList& args, const QDir &wrk)
@@ -302,6 +341,7 @@ void EditVBoxLayout::onProgramFinished(int exitCode, QProcess::ExitStatus exitSt
             disconnect(proc, QOverload<int, QProcess::ExitStatus, AbcProcess::ProcessType>::of(&AbcProcess::finished), this, &EditVBoxLayout::onProgramFinished);
             delete proc;
             processlist.removeAt(i);
+            break;
         }
     }
 }
@@ -339,6 +379,7 @@ void EditVBoxLayout::killSynth()
             disconnect(proc, QOverload<int, QProcess::ExitStatus, AbcProcess::ProcessType>::of(&AbcProcess::finished), this, &EditVBoxLayout::onProgramFinished);
             delete proc;
             processlist.removeAt(i);
+            break;
         }
     }
 }
