@@ -17,6 +17,7 @@
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QCheckBox>
+#include <QFontComboBox>
 
 class EditorPrefDialog : public QDialog
 {
@@ -28,6 +29,7 @@ public:
     QColor getColor(QString key);
     bool getHighlight();
     int getFontRange();
+    QFont getBaseFont();
 
 signals:
 
@@ -37,6 +39,9 @@ private slots:
 private:
     QVBoxLayout* mainLayout;
 
+    QLabel* fontLabel;
+    QFontComboBox* fontBaseCombo;
+
     QLabel* fontRangeLabel;
     QSpinBox* fontRangeSpinBox;
 
