@@ -17,27 +17,27 @@
 <context>
     <name>AbcPlainTextEdit</name>
     <message>
-        <location filename="AbcPlainTextEdit.cpp" line="61"/>
-        <location filename="AbcPlainTextEdit.cpp" line="161"/>
+        <location filename="AbcPlainTextEdit.cpp" line="70"/>
+        <location filename="AbcPlainTextEdit.cpp" line="209"/>
         <source>Find...</source>
         <translation>Rechercher...</translation>
     </message>
     <message>
-        <location filename="AbcPlainTextEdit.cpp" line="67"/>
-        <location filename="AbcPlainTextEdit.cpp" line="175"/>
+        <location filename="AbcPlainTextEdit.cpp" line="76"/>
+        <location filename="AbcPlainTextEdit.cpp" line="223"/>
         <source>Find forward</source>
         <translation>Rechercher en avant</translation>
     </message>
     <message>
-        <location filename="AbcPlainTextEdit.cpp" line="73"/>
-        <location filename="AbcPlainTextEdit.cpp" line="189"/>
+        <location filename="AbcPlainTextEdit.cpp" line="82"/>
+        <location filename="AbcPlainTextEdit.cpp" line="237"/>
         <source>Find backward</source>
         <translation>Rechercher en arrière</translation>
     </message>
     <message>
-        <location filename="AbcPlainTextEdit.cpp" line="161"/>
-        <location filename="AbcPlainTextEdit.cpp" line="175"/>
-        <location filename="AbcPlainTextEdit.cpp" line="189"/>
+        <location filename="AbcPlainTextEdit.cpp" line="209"/>
+        <location filename="AbcPlainTextEdit.cpp" line="223"/>
+        <location filename="AbcPlainTextEdit.cpp" line="237"/>
         <source>Text:</source>
         <translation>Texte :</translation>
     </message>
@@ -45,12 +45,12 @@
 <context>
     <name>EditTabWidget</name>
     <message>
-        <location filename="EditTabWidget.cpp" line="77"/>
+        <location filename="EditTabWidget.cpp" line="78"/>
         <source>Really close?</source>
         <translation>Fermer vraiment ?</translation>
     </message>
     <message>
-        <location filename="EditTabWidget.cpp" line="78"/>
+        <location filename="EditTabWidget.cpp" line="79"/>
         <source>Current score not saved!
 Close this score anyway?</source>
         <translation>La partition courante n&apos;est pas enregistrée !
@@ -60,83 +60,83 @@ Fermer cette partition quand-même ?</translation>
 <context>
     <name>EditVBoxLayout</name>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="33"/>
+        <location filename="EditVBoxLayout.cpp" line="32"/>
         <source>X:</source>
         <translation>X:</translation>
     </message>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="179"/>
+        <location filename="EditVBoxLayout.cpp" line="214"/>
         <source>Failed to start program: </source>
         <translation>Impossible de démarrer le programme : </translation>
     </message>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="180"/>
+        <location filename="EditVBoxLayout.cpp" line="215"/>
         <source>Please check settings.</source>
         <translation>Veuillez vérifier les paramètres.</translation>
     </message>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="361"/>
+        <location filename="EditVBoxLayout.cpp" line="402"/>
         <source>Generating MIDI for playing.</source>
         <translation>Génération du MIDI pour jouer.</translation>
     </message>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="366"/>
+        <location filename="EditVBoxLayout.cpp" line="407"/>
         <source>Stopping synthesis.</source>
         <translation>Arrêt de la synthèse.</translation>
     </message>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="377"/>
+        <location filename="EditVBoxLayout.cpp" line="418"/>
         <source>Error during MIDI generation.</source>
         <translation>Erreur pendant la génération du MIDI.</translation>
     </message>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="383"/>
+        <location filename="EditVBoxLayout.cpp" line="424"/>
         <source>MIDI generation finished.</source>
         <translation>Génération du MIDI terminée.</translation>
     </message>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="399"/>
+        <location filename="EditVBoxLayout.cpp" line="440"/>
         <source>Starting synthesis...</source>
         <translation>Démarrage de la synthèse...</translation>
     </message>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="409"/>
+        <location filename="EditVBoxLayout.cpp" line="450"/>
         <source>Synthesis finished.</source>
         <translation>Synthèse terminée.</translation>
     </message>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="426"/>
+        <location filename="EditVBoxLayout.cpp" line="467"/>
         <source>Generating score...</source>
         <translation>Génération de la partition...</translation>
     </message>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="452"/>
+        <location filename="EditVBoxLayout.cpp" line="493"/>
         <source>Refresh &amp;view</source>
         <translation>Rafraîchir la &amp;vue</translation>
     </message>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="457"/>
+        <location filename="EditVBoxLayout.cpp" line="498"/>
         <source>Error during score generation.</source>
         <translation>Erreur pendant la génération de la partition.</translation>
     </message>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="461"/>
+        <location filename="EditVBoxLayout.cpp" line="502"/>
         <source>Score generated.</source>
         <translation>Patition générée.</translation>
     </message>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="482"/>
+        <location filename="EditVBoxLayout.cpp" line="523"/>
         <source>Starting viewer...</source>
         <translation>Démarrage du visualiseur...</translation>
     </message>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="491"/>
+        <location filename="EditVBoxLayout.cpp" line="532"/>
         <source>Viewer closed.</source>
         <translation>Visualiseur fermé.</translation>
     </message>
     <message>
-        <location filename="EditVBoxLayout.cpp" line="196"/>
-        <location filename="EditVBoxLayout.cpp" line="498"/>
+        <location filename="EditVBoxLayout.cpp" line="231"/>
+        <location filename="EditVBoxLayout.cpp" line="539"/>
         <source>&amp;View score</source>
         <translation>&amp;Voir la partition</translation>
     </message>
@@ -150,46 +150,56 @@ Fermer cette partition quand-même ?</translation>
     </message>
     <message>
         <location filename="editorprefdialog.cpp" line="28"/>
+        <source>These settings will be applied on newly opened tabs only.</source>
+        <translation>Ces préférences ne seront appliquées qu&apos;aux nouvelles partitions ouvertes.</translation>
+    </message>
+    <message>
+        <location filename="editorprefdialog.cpp" line="32"/>
+        <source>Base font</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="editorprefdialog.cpp" line="46"/>
         <source>Font enlargement</source>
         <translation>Élargissement de la police</translation>
     </message>
     <message>
-        <location filename="editorprefdialog.cpp" line="40"/>
+        <location filename="editorprefdialog.cpp" line="59"/>
         <source>Highlight current line</source>
         <translation>Ligne courante en surbrillance</translation>
     </message>
     <message>
-        <location filename="editorprefdialog.cpp" line="51"/>
+        <location filename="editorprefdialog.cpp" line="71"/>
         <source>Header color</source>
         <translation>Couleur d&apos;en-tête</translation>
     </message>
     <message>
-        <location filename="editorprefdialog.cpp" line="52"/>
+        <location filename="editorprefdialog.cpp" line="72"/>
         <source>Comment color</source>
         <translation>Couleur de commentaire</translation>
     </message>
     <message>
-        <location filename="editorprefdialog.cpp" line="53"/>
+        <location filename="editorprefdialog.cpp" line="73"/>
         <source>Extra instruction color</source>
         <translation>Couleur d&apos; instruction</translation>
     </message>
     <message>
-        <location filename="editorprefdialog.cpp" line="54"/>
+        <location filename="editorprefdialog.cpp" line="74"/>
         <source>Measure bar color</source>
         <translation>Couleur de barre de mesure</translation>
     </message>
     <message>
-        <location filename="editorprefdialog.cpp" line="55"/>
+        <location filename="editorprefdialog.cpp" line="75"/>
         <source>Decoration color</source>
         <translation>Couleur de décoration</translation>
     </message>
     <message>
-        <location filename="editorprefdialog.cpp" line="56"/>
+        <location filename="editorprefdialog.cpp" line="76"/>
         <source>Guitar chord color</source>
         <translation>Couleur d&apos; accord de guitare</translation>
     </message>
     <message>
-        <location filename="editorprefdialog.cpp" line="57"/>
+        <location filename="editorprefdialog.cpp" line="77"/>
         <source>Lyric color</source>
         <translation>Couleur de parole</translation>
     </message>
@@ -350,92 +360,98 @@ QAbc version </translation>
         <translation>Partition</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="28"/>
+        <location filename="ScoreMenu.cpp" line="29"/>
+        <location filename="ScoreMenu.cpp" line="32"/>
         <source>New</source>
         <translation>Nouvelle</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="29"/>
+        <location filename="ScoreMenu.cpp" line="30"/>
+        <location filename="ScoreMenu.cpp" line="33"/>
         <source>Open</source>
         <translation>Ouvrir</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="37"/>
+        <location filename="ScoreMenu.cpp" line="42"/>
         <source>Recently opened</source>
         <translation>Ouvert récemment</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="43"/>
+        <location filename="ScoreMenu.cpp" line="49"/>
+        <location filename="ScoreMenu.cpp" line="54"/>
         <source>Save</source>
         <translation>Enregistrer</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="44"/>
+        <location filename="ScoreMenu.cpp" line="50"/>
+        <location filename="ScoreMenu.cpp" line="55"/>
         <source>Save as</source>
         <translation>Enregistrer sous</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="45"/>
+        <location filename="ScoreMenu.cpp" line="51"/>
+        <location filename="ScoreMenu.cpp" line="56"/>
         <source>Close</source>
         <translation>Fermer</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="46"/>
+        <location filename="ScoreMenu.cpp" line="52"/>
+        <location filename="ScoreMenu.cpp" line="57"/>
         <source>Quit</source>
         <translation>Quitter</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="64"/>
+        <location filename="ScoreMenu.cpp" line="76"/>
         <source>Really quit?</source>
         <translation>Quitter vraiment ?</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="66"/>
+        <location filename="ScoreMenu.cpp" line="78"/>
         <source> score(s) not saved.
 Do you want to quit anyway?</source>
         <translation> partition(s) non enregistrée(s).
 Voulez-vous quitter quand-même ?</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="86"/>
+        <location filename="ScoreMenu.cpp" line="98"/>
         <source>Open ABC Score</source>
         <translation>Ouvrir une partition ABC</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="86"/>
-        <location filename="ScoreMenu.cpp" line="216"/>
+        <location filename="ScoreMenu.cpp" line="98"/>
+        <location filename="ScoreMenu.cpp" line="228"/>
         <source>ABC score (*.abc)</source>
         <translation>Partition ABC (*.abc)</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="168"/>
-        <location filename="ScoreMenu.cpp" line="185"/>
-        <location filename="ScoreMenu.cpp" line="202"/>
+        <location filename="ScoreMenu.cpp" line="180"/>
+        <location filename="ScoreMenu.cpp" line="197"/>
+        <location filename="ScoreMenu.cpp" line="214"/>
         <source>Warning</source>
         <translation>Attention</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="168"/>
+        <location filename="ScoreMenu.cpp" line="180"/>
         <source>Could not open score!</source>
         <translation>Impossible d&apos;ouvrir la partition !</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="185"/>
+        <location filename="ScoreMenu.cpp" line="197"/>
         <source>Could not save an untitled ABC score!</source>
         <translation>Impossible d&apos;enregistrer une partition ABC sans titre !</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="199"/>
+        <location filename="ScoreMenu.cpp" line="211"/>
         <source>Score saved.</source>
         <translation>Partition enregistrée.</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="216"/>
+        <location filename="ScoreMenu.cpp" line="228"/>
         <source>Save ABC score</source>
         <translation>Enregistrer la partition ABC</translation>
     </message>
     <message>
-        <location filename="ScoreMenu.cpp" line="202"/>
+        <location filename="ScoreMenu.cpp" line="214"/>
         <source>Could not save ABC score!</source>
         <translation>Impossible d&apos;enregistrer la partition ABC !</translation>
     </message>
